@@ -63,9 +63,9 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
 
     metadata = metadata_module.PrimitiveMetadata({
         'id': '69845479-0b61-3578-b382-972cd0e61d69',
-        'version': '2.0.11',
+        'version': '2.0.12',
         'name': 'IPCMB feature selector',
-        'keywords': 'rpi primitives',
+        'keywords': ['rpi primitives'],
         'source': {
             'name': 'RPI',
             'uris': [
